@@ -52,6 +52,8 @@ class CollectionQueryset(object):
         self._query.set_collection(self._collection.name)
         self._query.clear()
 
+        return self
+
     def filter(self, bit_operator=Query.NO_BIT_OPERATOR, **kwargs):
         """
         """
@@ -60,6 +62,8 @@ class CollectionQueryset(object):
 
         self._query.filter(bit_operator=bit_operator, **kwargs)
 
+        return self
+
     def exclude(self, **kwargs):
         """
         """
@@ -68,6 +72,8 @@ class CollectionQueryset(object):
 
         self._query.exclude(**kwargs)
 
+        return self
+
     def limit(self, count, start=-1):
         """
         """
@@ -76,6 +82,8 @@ class CollectionQueryset(object):
 
         self._query.limit(count, start)
 
+        return self
+
     def _clone(self):
         """
         """
@@ -176,9 +184,27 @@ class CollectionModelManager(object):
         """
 
         queryset = CollectionQueryset(manager=self)
-        queryset.all()
+        return queryset.all()
 
-        return queryset
+    def filter(self, **kwargs):
+        """
+
+        :param kwargs:
+        :return:
+        """
+
+        queryset = CollectionQueryset(manager=self)
+        return queryset.all().filter(**kwargs)
+
+    def exclude(self, **kwargs):
+        """
+
+        :param kwargs:
+        :return:
+        """
+
+        queryset = CollectionQueryset(manager=self)
+        return queryset.all().exclude(**kwargs)
 
     def _create_model_from_doc(self, doc, model_class=None):
         """
@@ -332,9 +358,11 @@ class CollectionModel(object):
         cls._model_meta_data = cls.MetaDataObj()
 
         # Go through all fields
-        for attribute in cls.get_collection_fields():
+        fields_dict = cls.get_collection_fields_dict()
+        for attribute_name in fields_dict:
+            attribute = fields_dict[attribute_name]
             # Trigger init event
-            attribute.on_init(cls)
+            attribute.on_init(cls, attribute_name)
 
         # Go through all index
         model_index_list = cls.get_model_fields_index()
@@ -417,6 +445,11 @@ class CollectionModel(object):
                 if field_name in self._instance_meta_data._fields:
                     # Get field
                     field = self._instance_meta_data._fields[field_name]
+
+                    # Read only fields are ignored
+                    if field.read_only:
+                        continue
+
                     # Validate content by field
                     field.validate()
                     # Get content
