@@ -918,6 +918,60 @@ class CollectionModelManagerTestCase(unittest.TestCase):
 
         TestModel.destroy()
 
+    def test_filter_directly(self):
+
+        class TestModel(CollectionModel):
+            name = CharField()
+
+        TestModel.init()
+
+        model1 = TestModel()
+        model1.name = 'test'
+        model1.save()
+
+        model2 = TestModel()
+        model2.name = 'foo'
+        model2.save()
+
+        all_models = TestModel.objects.filter(name='foo')
+
+        self.assertEqual(len(all_models), 1)
+
+        model = all_models[0]
+
+        self.assertEqual(model.id, model2.id)
+
+        self.assertTrue(isinstance(model, TestModel))
+
+        TestModel.destroy()
+
+    def test_exclude_directly(self):
+
+        class TestModel(CollectionModel):
+            name = CharField()
+
+        TestModel.init()
+
+        model1 = TestModel()
+        model1.name = 'test'
+        model1.save()
+
+        model2 = TestModel()
+        model2.name = 'foo'
+        model2.save()
+
+        all_models = TestModel.objects.exclude(name='foo')
+
+        self.assertEqual(len(all_models), 1)
+
+        model = all_models[0]
+
+        self.assertEqual(model.id, model1.id)
+
+        self.assertTrue(isinstance(model, TestModel))
+
+        TestModel.destroy()
+
     def test_iterate_over_queryset(self):
 
         class TestModel(CollectionModel):
@@ -1321,6 +1375,63 @@ class ForeignkeyFieldTestCase(unittest.TestCase):
 
         self.assertEqual(field1.relation_model, model)
 
+    def test_other_side(self):
+
+        class OtherModel(CollectionModel):
+            my_side = ForeignKeyField(to=ForeignkeyFieldTestCase.TestModel, related_name='other_side')
+
+        OtherModel.init()
+
+        this_model = ForeignkeyFieldTestCase.TestModel()
+        this_model.save()
+
+        mo = OtherModel()
+        mo.my_side = this_model
+        mo.save()
+
+        mo2 = OtherModel()
+        mo2.my_side = this_model
+        mo2.save()
+
+        # print(this_model.other_side)
+
+        self.assertEqual(len(this_model.other_side), 2)
+
+        OtherModel.destroy()
+
+    def test_other_side_filtering(self):
+
+        class OtherModel(CollectionModel):
+            my_side = ForeignKeyField(to=ForeignkeyFieldTestCase.TestModel, related_name='other_side')
+            username = CharField()
+
+        OtherModel.init()
+
+        this_model = ForeignkeyFieldTestCase.TestModel()
+        this_model.save()
+
+        mo = OtherModel()
+        mo.my_side = this_model
+        mo.username = 'test'
+        mo.save()
+
+        mo2 = OtherModel()
+        mo2.my_side = this_model
+        mo2.username = 'not test'
+        mo2.save()
+
+        self.assertEqual(len(this_model.other_side), 2)
+
+        filtered_other_side = this_model.other_side.filter(username='test')
+
+        self.assertEqual(len(filtered_other_side), 1)
+
+        filtered_model = filtered_other_side[0]
+
+        self.assertEqual(filtered_model.id, mo.id)
+
+        OtherModel.destroy()
+
 
 class ManyToManyFieldTestCase(unittest.TestCase):
 
